stem_redis library

Classes

RedisHeartbeatTransport
Redis-backed transport that publishes encoded heartbeats to a channel.
RedisLockStore
Redis-backed implementation of LockStore.
RedisResultBackend
Redis-backed implementation of ResultBackend.
RedisRevokeStore
Redis-backed implementation of RevokeStore.
RedisScheduleStore
Redis-backed implementation of ScheduleStore.
RedisStreamsBroker
Redis streams-backed implementation of Broker.
RedisWorkflowStore
Redis-backed implementation of WorkflowStore.
StemRedisAdapter
Adapter that resolves Redis-backed factories from a redis:// URL.

Functions

redisBrokerFactory(String uri, {String namespace = 'stem', Duration blockTime = const Duration(seconds: 5), int delayedDrainBatch = 128, Duration defaultVisibilityTimeout = const Duration(seconds: 30), Duration claimInterval = const Duration(seconds: 30), TlsConfig? tls}) → StemBrokerFactory
Creates a StemBrokerFactory backed by Redis streams.
redisLockStoreFactory(String uri, {String namespace = 'stem', TlsConfig? tls}) → LockStoreFactory
Creates a LockStoreFactory backed by Redis.
redisResultBackendFactory(String uri, {String namespace = 'stem', Duration defaultTtl = const Duration(days: 1), Duration groupDefaultTtl = const Duration(days: 1), Duration heartbeatTtl = const Duration(minutes: 1), TlsConfig? tls}) → StemBackendFactory
Creates a StemBackendFactory backed by Redis.
redisRevokeStoreFactory(String uri, {String namespace = 'stem', TlsConfig? tls}) → RevokeStoreFactory
Creates a RevokeStoreFactory backed by Redis.
redisScheduleStoreFactory(String uri, {String namespace = 'stem', Duration lockTtl = const Duration(seconds: 5), ScheduleCalculator? calculator, TlsConfig? tls}) → ScheduleStoreFactory
Creates a ScheduleStoreFactory backed by Redis.
redisWorkflowStoreFactory(String uri, {String namespace = 'stem', TlsConfig? tls}) → WorkflowStoreFactory
Creates a WorkflowStoreFactory backed by Redis.

Typedefs

RedisHeartbeatCommandFactory = Future<({Command command, RedisConnection connection})> Function(Uri uri, TlsConfig? tls)
Factory for creating Redis connections used by the heartbeat transport.